/*   gnomview.h
* ===========================================================================
*
*                            PUBLIC DOMAIN NOTICE
*            National Center for Biotechnology Information (NCBI)
*
*  This software/database is a "United States Government Work" under the
*  terms of the United States Copyright Act.  It was written as part of
*  the author's official duties as a United States Government employee and
*  thus cannot be copyrighted.  This software/database is freely available
*  to the public for use. The National Library of Medicine and the U.S.
*  Government do not place any restriction on its use or reproduction.
*  We would, however, appreciate having the NCBI and the author cited in
*  any work or product based on this material
*
*  Although all reasonable efforts have been taken to ensure the accuracy
*  and reliability of the software and data, the NLM and the U.S.
*  Government do not and cannot warrant the performance or results that
*  may be obtained by using this software or data. The NLM and the U.S.
*  Government disclaim all warranties, express or implied, including
*  warranties of performance, merchantability or fitness for any particular
*  purpose.
*
* ===========================================================================
*
* File Name:  gnomview.h
*
* Author:  Jonathan Kans
*
* Version Creation Date:   4/30/95
*
* $Revision: 6.0 $
*
* File Description: 
*
* Modifications:  
* --------------------------------------------------------------------------
* Date     Name        Description of modification
* -------  ----------  -----------------------------------------------------
*
*
* ==========================================================================
*/

#ifndef _GNOMVIEW_
#define _GNOMVIEW_

#ifdef __cplusplus
extern "C" {
#endif

#include <dlogutil.h>
#include <document.h>
#include <viewer.h>

/*
*  The GenomeViewProcsPtr may be registered with a call to SetAppProperty
*  e.g., SetAppProperty ("GenomeDisplayForm", &viewprocs), where viewprocs
*  is a persistent structure filled with callback function pointers specific
*  for a given application.
*/

typedef struct genomeviewprocs {
  Boolean          asnObjectReport;
  Boolean          launchSubviewers;
  Boolean          sendSelectMessages;
  Boolean          highlightSelections;

  Boolean          cleanupObjectPtr;
  WndActnProc      activateForm;
  WndActnProc      closeForm;
  WndActnProc      createMenus;
  Boolean          showAsnPage;

  FormMessageFunc  handleMessages;

  Int2             minPixelWidth;
  Int2             minPixelHeight;
  Int2             initPage;
  Int2             useFolderTabs;
} GenomeViewProcs, PNTR GenomeViewProcsPtr;

#define REGISTER_GENOME_VIEW ObjMgrProcLoad(OMPROC_VIEW,"View Genome Report","Genome Report",OBJ_BIOSEQ,0,OBJ_BIOSEQ,0,NULL,GenomeViewGenFunc,PROC_PRIORITY_DEFAULT)

#define GENOMEMAP_PAGE       0
#define GENOMEGRAPHIC_PAGE   1
#define GENOMEALIGN_PAGE     2
#define GENOMEASN1_PAGE      3

extern ForM LIBCALL CreateGenomeViewForm (Int2 left, Int2 top, CharPtr title,
                                          SeqEntryPtr sep,
                                          GenomeViewProcsPtr gvpp);

extern Int2 LIBCALLBACK GenomeViewGenFunc (Pointer data);

extern void LIBCALL CopyGenomeViewFormToClipboard (Pointer formDataPtr);
extern void LIBCALL PrintGenomeViewForm (Pointer formDataPtr);
extern void LIBCALL ExportGenomeViewFormToFile (Pointer formDataPtr, CharPtr filename);

extern void LaunchSubViewer (Uint2 entityID, Uint2 itemID, Uint2 itemtype, Pointer userdata);

#ifdef __cplusplus
}
#endif

#endif /* ndef _GNOMVIEW_ */

