/*   mmdbview.h
* ===========================================================================
*
*                            PUBLIC DOMAIN NOTICE
*            National Center for Biotechnology Information (NCBI)
*
*  This software/database is a "United States Government Work" under the
*  terms of the United States Copyright Act.  It was written as part of
*  the author's official duties as a United States Government employee and
*  thus cannot be copyrighted.  This software/database is freely available
*  to the public for use. The National Library of Medicine and the U.S.
*  Government do not place any restriction on its use or reproduction.
*  We would, however, appreciate having the NCBI and the author cited in
*  any work or product based on this material
*
*  Although all reasonable efforts have been taken to ensure the accuracy
*  and reliability of the software and data, the NLM and the U.S.
*  Government do not and cannot warrant the performance or results that
*  may be obtained by using this software or data. The NLM and the U.S.
*  Government disclaim all warranties, express or implied, including
*  warranties of performance, merchantability or fitness for any particular
*  purpose.
*
* ===========================================================================
*
* File Name:  mmdbview.h
*
* Author:  Jonathan Kans
*
* Version Creation Date:   8/17/95
*
* $Revision: 6.0 $
*
* File Description: 
*
* Modifications:  
* --------------------------------------------------------------------------
* Date     Name        Description of modification
* -------  ----------  -----------------------------------------------------
*
*
* ==========================================================================
*/

#ifndef _MMDBVIEW_
#define _MMDBVIEW_

#ifdef __cplusplus
extern "C" {
#endif

#include <dlogutil.h>
#include <document.h>

#include <mmdbapi.h>

/*
*  The BiostrucViewProcsPtr may be registered with a call to SetAppProperty
*  e.g., SetAppProperty ("BiostrucDisplayForm", &viewprocs), where viewprocs
*  is a persistent structure filled with callback function pointers specific
*  for a given application.
*/

typedef struct biostrucviewprocs {
  Boolean          cleanupObjectPtr;
  WndActnProc      activateForm;
  WndActnProc      closeForm;
  WndActnProc      createMenus;
  Boolean          showAsnPage;

  FormMessageFunc  handleMessages;

  Int2             minPixelWidth;
  Int2             minPixelHeight;
  Int2             initPage;
  Int2             useFolderTabs;

  Int2             kinColorView;
  Int2             kinRenderingFlags;
} BiostrucViewProcs, PNTR BiostrucViewProcsPtr;

#define PDB_PAGE           0
#define KINEMAGE_PAGE      1
#define BIOSTRUCASN1_PAGE  2

extern ForM LIBCALL CreateBiostrucViewForm (Int2 left, Int2 top, CharPtr title,
                                    PDNMS pdnms, CharPtr asnFileName,
                                    BiostrucViewProcsPtr bvpp);

extern void LIBCALL PrintBiostrucViewForm (Pointer formDataPtr);
extern void LIBCALL ExportBiostrucViewFormToFile (Pointer formDataPtr, CharPtr filename);


#ifdef __cplusplus
}
#endif

#endif /* ndef _MMDBVIEW_ */

