/*   seqview.h
* ===========================================================================
*
*                            PUBLIC DOMAIN NOTICE
*            National Center for Biotechnology Information (NCBI)
*
*  This software/database is a "United States Government Work" under the
*  terms of the United States Copyright Act.  It was written as part of
*  the author's official duties as a United States Government employee and
*  thus cannot be copyrighted.  This software/database is freely available
*  to the public for use. The National Library of Medicine and the U.S.
*  Government do not place any restriction on its use or reproduction.
*  We would, however, appreciate having the NCBI and the author cited in
*  any work or product based on this material
*
*  Although all reasonable efforts have been taken to ensure the accuracy
*  and reliability of the software and data, the NLM and the U.S.
*  Government do not and cannot warrant the performance or results that
*  may be obtained by using this software or data. The NLM and the U.S.
*  Government disclaim all warranties, express or implied, including
*  warranties of performance, merchantability or fitness for any particular
*  purpose.
*
* ===========================================================================
*
* File Name:  seqview.h
*
* Author:  Jonathan Kans
*
* Version Creation Date:   4/30/95
*
* $Revision: 6.0 $
*
* File Description: 
*
* Modifications:  
* --------------------------------------------------------------------------
* Date     Name        Description of modification
* -------  ----------  -----------------------------------------------------
*
*
* ==========================================================================
*/

#ifndef _SEQVIEW_
#define _SEQVIEW_

#ifdef __cplusplus
extern "C" {
#endif

#include <dlogutil.h>
#include <viewer.h>

/*
*  The SequenceViewProcsPtr may be registered with a call to SetAppProperty
*  e.g., SetAppProperty ("SequenceDisplayForm", &viewprocs), where viewprocs
*  is a persistent structure filled with callback function pointers specific
*  for a given application.
*/

typedef struct sequenceviewprocs {
  Boolean          asnObjectReport;
  Boolean          launchEditors;
  Boolean          launchSubviewers;
  Boolean          sendSelectMessages;
  Boolean          highlightSelections;

  Boolean          cleanupObjectPtr;
  WndActnProc      activateForm;
  WndActnProc      closeForm;
  WndActnProc      createMenus;
  Boolean          showAsnPage;

  FormMessageFunc  handleMessages;

  Int2             minPixelWidth;
  Int2             minPixelHeight;
  Int2             initNucPage;
  Int2             initProtPage;
  Int2             useFolderTabs;
  Boolean          useScrollText;

  FonT             headingFont;
  FonT             referenceFont;
  FonT             sequenceFont;
  FonT             standardFont;
  FonT             displayFont;
  Int2             charsPerLine;

  CharPtr          filepath;
} SequenceViewProcs, PNTR SequenceViewProcsPtr;

/* BIOSEQ_VIEW targets a single Bioseq.  SEQENTRY_VIEW switches between components. */

#define REGISTER_BIOSEQ_VIEW ObjMgrProcLoad(OMPROC_VIEW,"View Bioseq Report","Bioseq Report",OBJ_BIOSEQ,0,OBJ_BIOSEQ,0,NULL,BioseqViewGenFunc,PROC_PRIORITY_DEFAULT)
#define REGISTER_SEQENTRY_VIEW ObjMgrProcLoad(OMPROC_VIEW,"View Bioseq Report","Bioseq Report",OBJ_BIOSEQ,0,OBJ_BIOSEQ,0,NULL,SeqEntryViewGenFunc,PROC_PRIORITY_DEFAULT)

#define NUCREPORT_PAGE    0
#define NUCGRAPHIC_PAGE   1
#define NUCALIGN_PAGE     2
#define NUCASN2FF_PAGE_1  3
#define NUCASN2FF_PAGE_2  4
#define NUCFASTA_PAGE     5
#define NUCASN1_PAGE      6

#define PROTREPORT_PAGE    0
#define PROTGRAPHIC_PAGE   1
#define PROTALIGN_PAGE     2
#define PROTGENPEPT_PAGE   3
#define PROTFASTA_PAGE     4
#define PROTASN1_PAGE      5

extern ForM LIBCALL CreateBioseqViewForm (Int2 left, Int2 top, CharPtr title,
                                  BioseqPtr bsp,
                                  SequenceViewProcsPtr svpp);

extern Int2 LIBCALLBACK BioseqViewGenFunc (Pointer data);

extern ForM LIBCALL CreateSeqEntryViewForm (Int2 left, Int2 top, CharPtr title,
                                            BioseqPtr bsp,
                                            SequenceViewProcsPtr svpp);

extern Int2 LIBCALLBACK SeqEntryViewGenFunc (Pointer data);

extern void LIBCALL CopyBioseqViewFormToClipboard (Pointer formDataPtr);
extern void LIBCALL PrintBioseqViewForm (Pointer formDataPtr);
extern void LIBCALL ExportBioseqViewFormToFile (Pointer formDataPtr, CharPtr filename);
extern void LIBCALL SaveBioseqViewFormGifItemTable (Pointer formDataPtr, CharPtr filename);

/*************************************************************************
*
*       Find_segment_IDs(): Returns identifier triplet given a mouse point
*
*************************************************************************/
extern Boolean Find_segment_IDs PROTO((VieweR viewer, PoinT pt, Uint2Ptr entityID, Uint2Ptr itemID, Uint2Ptr itemType));

#ifdef __cplusplus
}
#endif

#endif /* ndef _SEQVIEW_ */

